///
///    This file is part of ILNumerics Community Edition.
///
///    ILNumerics Community Edition - high performance computing for applications.
///    Copyright (C) 2006 - 2012 Haymo Kutschbach, http://ilnumerics.net
///
///    ILNumerics Community Edition is free software: you can redistribute it and/or modify
///    it under the terms of the GNU General Public License version 3 as published by
///    the Free Software Foundation.
///
///    ILNumerics Community Edition is distributed in the hope that it will be useful,
///    but WITHOUT ANY WARRANTY; without even the implied warranty of
///    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
///    GNU General Public License for more details.
///
///    You should have received a copy of the GNU General Public License
///    along with ILNumerics Community Edition. See the file License.txt in the root
///    of your distribution package. If not, see <http://www.gnu.org/licenses/>.
///
///    In addition this software uses the following components and/or licenses: 
///
///    =================================================================================
///    The Open Toolkit Library License
///    
///    Copyright (c) 2006 - 2009 the Open Toolkit library.
///    
///    Permission is hereby granted, free of charge, to any person obtaining a copy
///    of this software and associated documentation files (the "Software"), to deal
///    in the Software without restriction, including without limitation the rights to 
///    use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
///    the Software, and to permit persons to whom the Software is furnished to do
///    so, subject to the following conditions:
///
///    The above copyright notice and this permission notice shall be included in all
///    copies or substantial portions of the Software.
///
///    =================================================================================
///    

using System;
using System.Collections.Generic;
using System.Text;
using System.Drawing; 
using ILNumerics.Drawing.Labeling; 

namespace ILNumerics.Drawing.Interfaces {
    /// <summary>
    /// interface for classes capable of transforming text 
    /// expressions into visual output representation
    /// </summary>
    /// <seealso cref="ILNumerics.Drawing.Labeling.ILSimpleTexInterpreter"/>
    public interface IILTextInterpreter {
        /// <summary>
        /// transform text element (text) into bitmap for rendering
        /// </summary>
        /// <param name="expression">item text expression, defines the visual output content</param>
        /// <param name="font">font used for rendering the text</param>
        /// <param name="color">initial color, unless overridden, used for items in expression</param>
        /// <param name="renderer">IILTextRenderer implementation, used for caching the element(s)</param>
        /// <returns>renderer queue, contains item keys and the size of transformed item expression</returns>
        /// <remarks>The implementation should use the general caching capabilities 
        /// of the renderer class. Therefore the item's elements must be cached subsequently
        /// into the renderer before drawing. The render queue returned may be 
        /// used for rendering in the same renderer than.</remarks>
        ILRenderQueue Transform(
                string expression, Font font, Color color, IILTextRenderer renderer);  
    }
}
