///
///    This file is part of ILNumerics Community Edition.
///
///    ILNumerics Community Edition - high performance computing for applications.
///    Copyright (C) 2006 - 2012 Haymo Kutschbach, http://ilnumerics.net
///
///    ILNumerics Community Edition is free software: you can redistribute it and/or modify
///    it under the terms of the GNU General Public License version 3 as published by
///    the Free Software Foundation.
///
///    ILNumerics Community Edition is distributed in the hope that it will be useful,
///    but WITHOUT ANY WARRANTY; without even the implied warranty of
///    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
///    GNU General Public License for more details.
///
///    You should have received a copy of the GNU General Public License
///    along with ILNumerics Community Edition. See the file License.txt in the root
///    of your distribution package. If not, see <http://www.gnu.org/licenses/>.
///
///    In addition this software uses the following components and/or licenses: 
///
///    =================================================================================
///    The Open Toolkit Library License
///    
///    Copyright (c) 2006 - 2009 the Open Toolkit library.
///    
///    Permission is hereby granted, free of charge, to any person obtaining a copy
///    of this software and associated documentation files (the "Software"), to deal
///    in the Software without restriction, including without limitation the rights to 
///    use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
///    the Software, and to permit persons to whom the Software is furnished to do
///    so, subject to the following conditions:
///
///    The above copyright notice and this permission notice shall be included in all
///    copies or substantial portions of the Software.
///
///    =================================================================================
///    

using System;
using System.Collections.Generic;
using System.Drawing; 
using System.Text;

namespace ILNumerics.Drawing.Interfaces {

    /// <summary>
    /// definition of vertex data &amp; properties
    /// </summary>
    public interface IILVertexDefinition {
        /// <summary>
        /// determine, if the vertex is able to store individual alpha values
        /// </summary>
        bool StoresAlpha { get; }
        /// <summary>
        /// determine, if the vertex is able to store individual color values
        /// </summary>
        bool StoresColor { get; }
        /// <summary>
        /// determine, if the vertex is able to store normal data 
        /// </summary>
        bool StoresNormals { get; }
        /// <summary>
        /// Get/set the alpha value for the vertex
        /// </summary>
        byte Alpha { get; set; }
        /// <summary>
        /// Set the color for the vertex, alpha value is not modified!
        /// </summary>
        Color Color { get; set; }
        /// <summary>
        /// get/set position (X,Y,Z values) for the vertex 
        /// </summary>
        ILPoint3Df Position { get; set; }
        /// <summary>
        /// Get/set the normal vector for the value (see also: AutoCalculateNormals) 
        /// </summary>
        ILPoint3Df Normal { get; set; }
        /// <summary>
        /// get/set the X coordinate value for the vertex
        /// </summary>
        float XPosition { get; set; }
        /// <summary>
        /// get/set the Y coordinate value for the vertex
        /// </summary>
        float YPosition { get; set; }
        /// <summary>
        /// get/set the Z coordinate value for the vertex
        /// </summary>
        float ZPosition { get; set; }
        /// <summary>
        /// size of single vertex in bytes
        /// </summary>
        int VertexSize { get; }
    }

}
